@@ -15,7 +15,7 @@ single line of code. This gets achieved within
 
 So for to add help support to the widgets of your app
 you only need to add/provide the help texts with a help id
-that is matching the value of the :attr:`ae_help_id`
+that is matching the value of the :attr:`help_id`
 attribute of the widget you need help for.
 
 Additionally you can provide a separate i18n translation
@@ -141,7 +141,7 @@ pluralize-able help texts
 
 Each message id can optionally have several different
 help texts for their pluralization. For that
-simply add a `count` item to the `ae_help_vars`
+simply add a `count` item to the `help_vars`
 property of the help target widget and then
 define a help text for the all the possible
 count cases in your message text file
@@ -234,7 +234,7 @@ from ae.i18n import default_language, get_f_string, translation
 from ae.gui_app import FLOW_KEY_SEP, module_globals, id_of_flow, MainAppBase                # type: ignore
 
 
-__version__ = '0.1.9'
+__version__ = '0.1.10'
 
 
 HELP_ID_PREFIX_FLOW = 'help_flow#'                                  #: message id prefix for flow change help texts
@@ -554,7 +554,7 @@ class HelpAppBase(MainAppBase, ABC):
     def help_widget(self, help_id: str, help_vars: Dict[str, Any]) -> Any:
         """ ensure/find help target widget via attribute name/value and extend :paramref:`~help_widget.help_vars`.
 
-        :param help_id:         widget.ae_help_id attribute value for to detect widget and call stack locals.
+        :param help_id:         widget.help_id attribute value for to detect widget and call stack locals.
         :param help_vars:       help env variables, to be extended with event activation stack frame locals
                                 and a 'self' key with the help target widget.
         :return:                found help target widget or self.help_activator if not found.
@@ -567,15 +567,15 @@ class HelpAppBase(MainAppBase, ABC):
                 while depth <= 15:
                     _gfv, lfv, _deep = stack_vars("", min_depth=depth, max_depth=depth)  # "" to not skip ae.kivy_help
                     widget = lfv.get('self')
-                    if getattr(widget, 'ae_help_id', None) == help_id:
+                    if getattr(widget, 'help_id', None) == help_id:
                         help_vars.update(lfv)
                         return widget
                     depth += 1
 
                 # then search the widget tree
-                wid = self.widget_by_attribute('ae_help_id', help_id)
+                wid = self.widget_by_attribute('help_id', help_id)
                 if not wid:
-                    self.vpo(f"HelpAppBase.help_widget(): widget with ae_help_id '{help_id}' not found")
+                    self.vpo(f"HelpAppBase.help_widget(): widget with help_id '{help_id}' not found")
 
             if not wid:
                 wid = self.help_activator
